Function buffer_get_default_ts_type

pub fn buffer_get_default_ts_type(buffer: BufferId) -> Result<SortingOrder>
Gets the default sorting timestamp type of a buffer.

This is the timestamp type that will be used for sorting by default. We assume that it is always available and the input is sorted by it.

Returns

  • Ok(SortingOrder) - The default timestamp type of the passed buffer.
  • Err(std::io::Error) - An error.

Errors