pub fn buffer_check_ts_type_available(
buffer: BufferId,
stamp_type: SortingOrder,
) -> Result<bool>Expand description
Checks if a buffer contains timestamps of a given type.
If false is returned, the timestamp may still be available in some of the logs.
However, if true is returned, the timestamp will always be available.
You can check the timestamp availability per log using the get_timestamp
function.
Returns
Ok(bool)- Whether the given timestamp type is guaranteed to be available.Err(std::io::Error)- An error.
Errors
std::io::ErrorKind::InvalidInput- More than one buffer.std::io::ErrorKind::InvalidInput- One of the pointers was NULL.std::io::ErrorKind::Uncategorized- Couldn’t read config file.