pub fn buffer_get_default_ts_type(buffer: BufferId) -> Result<SortingOrder>Expand description
Gets the default sorting timestamp type of a buffer.
This is the timestamp type that will be used for sorting by default. We assume that it is always available and the input is sorted by it.
Returns
Ok(SortingOrder)- The default timestamp type of the passed buffer.Err(std::io::Error)- An error.
Errors
std::io::ErrorKind::InvalidInput- One of the pointers was NULL.std::io::ErrorKind::Uncategorized- Couldn’t read config file.